]> source.dussan.org Git - sonarqube.git/commitdiff
Analyze naming convention to travis.sh env variable GITHUB_TOKEN
authorSimon Brandhof <simon.brandhof@sonarsource.com>
Mon, 30 Nov 2015 08:21:35 +0000 (09:21 +0100)
committerSimon Brandhof <simon.brandhof@sonarsource.com>
Mon, 30 Nov 2015 08:21:35 +0000 (09:21 +0100)
travis.sh

index 91607fe1938e1d5bad9e33ce93123b1a3ec8d15f..d3972b454610e082ef7061458f90cea0ded7c8ef 100755 (executable)
--- a/travis.sh
+++ b/travis.sh
@@ -16,11 +16,11 @@ function strongEcho {
 case "$TARGET" in
 
 CI)
-  if [ "$TRAVIS_PULL_REQUEST" != "false" ] && [ -n "$SONAR_GITHUB_OAUTH" ]; then
+  if [ "$TRAVIS_PULL_REQUEST" != "false" ] && [ -n "$GITHUB_TOKEN" ]; then
     # For security reasons environment variables are not available on the pull requests
     # coming from outside repositories
     # http://docs.travis-ci.com/user/pull-requests/#Security-Restrictions-when-testing-Pull-Requests
# That's why the analysis does not need to be executed if the variable SONAR_GITHUB_OAUTH is not defined.
 
     strongEcho 'Build and analyze pull request'
     # this pull request must be built and analyzed (without upload of report)
@@ -34,7 +34,7 @@ CI)
         -Dsonar.analysis.mode=issues \
         -Dsonar.github.pullRequest=$TRAVIS_PULL_REQUEST \
         -Dsonar.github.repository=$TRAVIS_REPO_SLUG \
-        -Dsonar.github.oauth=$SONAR_GITHUB_OAUTH \
+        -Dsonar.github.oauth=$GITHUB_TOKEN \
         -Dsonar.host.url=$SONAR_HOST_URL \
         -Dsonar.login=$SONAR_LOGIN \
         -Dsonar.password=$SONAR_PASSWORD
@@ -76,7 +76,7 @@ WEB)
   ;;
 
 IT)
-  if [ "$IT_CATEGORY" == "Plugins" ] && [ -n "$SONAR_GITHUB_OAUTH" ]; then
+  if [ "$IT_CATEGORY" == "Plugins" ] && [ -n "$GITHUB_TOKEN" ]; then
     echo "This job is ignored as it needs to access a private GitHub repository"
   else
     installTravisTools
@@ -16,11 +16,11 @@ function strongEcho {
     # coming from outside repositories
     # http://docs.travis-ci.com/user/pull-requests/#Security-Restrictions-when-testing-Pull-Requests
-    # That's why the analysis does not need to be executed if the variable SONAR_GITHUB_OAUTH is not defined.
+    # That's why the analysis does not need to be executed if the variable GITHUB_TOKEN is not defined.
 
     strongEcho 'Build and analyze pull request'